==> ttvm_core-0.2.5.crate: ttvm_core-0.2.5/src/lib.rs <==
pub mod mem;

pub use mem::*;

#[cfg(test)]
mod tests {
    
    #[test]
    fn test_immut() {
        use crate::*;

        fn test_new() {
            let immut_mem = Immut::new(12);

            let _get_ok = match immut_mem.get(11) {
                Ok(ok) => assert_eq!(ok, 0x0),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(12) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 12);
            assert_eq!(immut_mem.clone_into_vec(), vec![0x0; 12]);
        }

        fn test_from() {
            let immut_mem = Immut::from(vec![1, 2, 3, 4, 5]);

            let _get_ok = match immut_mem.get(2) {
                Ok(ok) => assert_eq!(ok, 3),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(5) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 5);
            assert_eq!(immut_mem.clone_into_vec(), vec![1, 2, 3, 4, 5]);
        }

        fn test_from_mut() {
            let mut_mem = Mut::from(vec![1, 2, 3, 4, 5]);
            let immut_mem = Immut::from_mut(mut_mem);

            let _get_ok = match immut_mem.get(2) {
                Ok(ok) => assert_eq!(ok, 3),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(5) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 5);
            assert_eq!(immut_mem.clone_into_vec(), vec![1, 2, 3, 4, 5]);
        }
        
        test_new();
        test_from();
        test_from_mut()
    }

    #[test]
    fn test_mut() {
        use crate::*;

        fn test_new() {
            let mut mut_mem = Mut::new(12);
            let index11 = '😎' as Byte;

            let _set_ok = match mut_mem.set(11, index11) {
                Ok(ok) => assert_eq!(ok, ()),
                Err(err) => panic!("{}", err)
            };

            let _set_err = match mut_mem.set(12, 0x0) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            let _get_ok = match mut_mem.get(11) {
                Ok(ok) => assert_eq!(ok, index11),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match mut_mem.get(12) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(mut_mem.len(), 12);
            assert_eq!(mut_mem.clone_into_vec(), vec![0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, index11]);
        }

        test_new();
    }
}

==> ttvm_core-0.2.8.crate: ttvm_core-0.2.8/src/lib.rs <==
pub mod mem;
pub mod rtne;
pub mod arch;
pub mod exec;

pub use mem::*;
pub use rtne::*;
pub use arch::*;
pub use exec::*;

#[cfg(test)]
mod tests {
    pub use super::*;
    
    #[test]
    fn test_immut() {
        fn test_new() {
            let immut_mem = Immut::new(12);

            let _get_ok = match immut_mem.get(11) {
                Ok(ok) => assert_eq!(ok, 0x0),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(12) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 12);
            assert_eq!(immut_mem.clone_into_vec(), vec![0x0; 12]);
        }

        fn test_from() {
            let immut_mem = Immut::from(vec![1, 2, 3, 4, 5]);

            let _get_ok = match immut_mem.get(2) {
                Ok(ok) => assert_eq!(ok, 3),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(5) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 5);
            assert_eq!(immut_mem.clone_into_vec(), vec![1, 2, 3, 4, 5]);
        }

        fn test_from_mut() {
            let mut_mem = Mut::from(vec![1, 2, 3, 4, 5]);
            let immut_mem = Immut::from_mut(mut_mem);

            let _get_ok = match immut_mem.get(2) {
                Ok(ok) => assert_eq!(ok, 3),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match immut_mem.get(5) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(immut_mem.len(), 5);
            assert_eq!(immut_mem.clone_into_vec(), vec![1, 2, 3, 4, 5]);
        }
        
        test_new();
        test_from();
        test_from_mut()
    }

    #[test]
    fn test_mut() {
        fn test_new() {
            let mut mut_mem = Mut::new(12);
            let index11 = '😎' as Byte;

            let _set_ok = match mut_mem.set(11, index11) {
                Ok(ok) => assert_eq!(ok, ()),
                Err(err) => panic!("{}", err)
            };

            let _set_err = match mut_mem.set(12, 0x0) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            let _get_ok = match mut_mem.get(11) {
                Ok(ok) => assert_eq!(ok, index11),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match mut_mem.get(12) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(mut_mem.len(), 12);
            assert_eq!(mut_mem.clone_into_vec(), vec![0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, index11]);
        }

        fn test_from() {
            let mut mut_mem = Mut::from(vec![0x0; 12]);
            let index11 = '😎' as Byte;

            let _set_ok = match mut_mem.set(11, index11) {
                Ok(ok) => assert_eq!(ok, ()),
                Err(err) => panic!("{}", err)
            };

            let _set_err = match mut_mem.set(12, 0x0) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            let _get_ok = match mut_mem.get(11) {
                Ok(ok) => assert_eq!(ok, index11),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match mut_mem.get(12) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(mut_mem.len(), 12);
            assert_eq!(mut_mem.clone_into_vec(), vec![0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, index11]);
        }

        fn test_from_immut() {
            let immut_mem = Immut::from(vec![1, 2, 3, 4, 5]);
            let mut_mem = Mut::from_immut(immut_mem);

            let _get_ok = match mut_mem.get(2) {
                Ok(ok) => assert_eq!(ok, 3),
                Err(err) => panic!("{}", err)
            };

            let _get_err = match mut_mem.get(5) {
                Ok(_ok) => assert!(false),
                Err(_err) => assert!(true)
            };

            assert_eq!(mut_mem.len(), 5);
            assert_eq!(mut_mem.clone_into_vec(), vec![1, 2, 3, 4, 5]);
        }

        test_new();
        test_from();
        test_from_immut();
    }

    #[test]
    fn test_routine() {
        fn test_new() {
            let mut rtne = Routine::new();

            rtne.push(10);
            
            let pop_ok = rtne.pop();

            assert_eq!(pop_ok.unwrap(), 10);

            let pop_err = rtne.pop();

            assert_eq!(pop_err, None);

            assert_eq!(rtne.len(), 0);
            assert_eq!(rtne.clone_into_vec(), vec![]);
        }

        fn test_from() {
            let mut rtne = Routine::from(vec![]);

            rtne.push(10);
            
            let pop_ok = rtne.pop();

            assert_eq!(pop_ok.unwrap(), 10);

            let pop_err = rtne.pop();

            assert_eq!(pop_err, None);

            assert_eq!(rtne.len(), 0);
            assert_eq!(rtne.clone_into_vec(), vec![]);
        }

        test_new();
        test_from();
    }

    #[test]
    fn test_arch() {
        assert_eq!(WRITE_SCR, 0x57);
    }

    #[test]
    fn test_execute() {
        let rtne = Routine::from(vec![WRITE_SCR, '@' as Byte, WRITE_SCR, 0xA]);
        let result = execute(rtne);

        assert_eq!(result, None)
    }
}
